
%This mfile was created in Matlab R2010b.  Results were published in the
%following paper (Mackey and Lamb, 2013).  Please cite the following paper should these codes be
%used for a publication.

%Mackey, B.H., and Lamb, M.P., 2013, 
%Deciphering boulder mobility and erosion from cosmogenic nuclide exposure dating: 
%Journal of Geophysical Research: Earth Surface,doi: 10.1002/jgrf.20035

%Disclaimer:  These codes have only been tested for the conditions published
%in the manuscript. Numerical errors are likely outside of these bounds given
%the crude iteration schemes used.  Use at your own risk.

%Copyright (C) 2012 Michael Lamb <mpl@gps.caltech.edu>

% This program is free software: you can redistribute it and/or modify it 
% under the terms of the GNU General Public License as published by the 
% Free Software Foundation. You should have received a copy of the GNU 
% General Public License along with this program.  If not, see 
% http://www.gnu.org/licenses.


%makes a vertical profile through a boulder for a range of boulder sizes

radius = [0.1,0.25,0.5,1,1.5,2,3,4,5].*1000; %converts selected radii from m to mm

s = 1

for s = 1:length(radius)


rho = radius(s); %circle radius (mm)

%First set up the boulder framwork with a polar matrix
spokes = 5;
nodes = 100;

r = linspace(0,rho,nodes); %the spoke separated into evenly seperated nodes
theta = linspace(0,2*pi,spokes)'; %Angular interval of spokes
Xcol = []; %big column of all x values
Ycol = []; %big column lf all y values
m = 1; %increment

for m = 1:nodes;
    [X,Y]=pol2cart(theta,r(m)); %Cartesian coordinates of each concentric ring
    
    Xcol = [Xcol;X];
    Ycol = [Ycol;Y];
end

Lx = length(Xcol);
y_alt(1:Lx)=0; %makes it a 2-D disc

[accum] = sphere_line3_Lal(Xcol./1000, y_alt./1000, Ycol./1000, rho./1000); %this function assumes meters
accum = accum.*0.5252; %conversion for normalization by flat surface and all rays


vertprof = [fliplr(accum(4:5:end))';accum(2:5:end)'];
vertdist = linspace(0,2*rho,2*nodes)';

eval(['vertprof' num2str(rho) '=vertprof']);
eval(['vertdist' num2str(rho) '=vertdist']);

clear accum vertprof vertdist
 
end

ndspoke = linspace(0,1,200);

figure
subplot(2,1,1)
pl1 = plot(vertprof100,vertdist100, 'k-');
hold on
pl2 = plot(vertprof250,vertdist250);
pl3 = plot(vertprof500,vertdist500, 'k--');
pl4 = plot(vertprof1000,vertdist1000);
pl5 = plot(vertprof1500,vertdist1500, 'k.-');
pl6 = plot(vertprof2000,vertdist2000);
pl7 = plot(vertprof3000,vertdist3000, 'k:');
pl8 = plot(vertprof4000,vertdist4000);
pl9 = plot(vertprof5000,vertdist5000, 'r-');
xlabel('Nuclide concentration (atoms/node)')
ylabel('Vertical axis length (mm)')

subplot(2,1,2)
pl21 = plot(vertprof100,ndspoke, 'k-');
hold on
pl22 = plot(vertprof250,ndspoke);
pl23 = plot(vertprof500,ndspoke,'k--');
pl24 = plot(vertprof1000,ndspoke);
pl25 = plot(vertprof1500,ndspoke, 'k.-');
pl26 = plot(vertprof2000,ndspoke);
pl27 = plot(vertprof3000,ndspoke, 'k:');
pl28 = plot(vertprof4000,ndspoke)
pl29 = plot(vertprof5000,ndspoke, 'r-');
xlabel('Nuclide concentration (atoms/node)')
ylabel('Normalized vertical axis length')

