%This mfile was created in Matlab R2010b.  Results were published in the
%following paper (Mackey and Lamb, 2013).  Please cite the following paper should these codes be
%used for a publication.

%Mackey, B.H., and Lamb, M.P., 2013, 
%Deciphering boulder mobility and erosion from cosmogenic nuclide exposure dating: 
%Journal of Geophysical Research: Earth Surface,doi: 10.1002/jgrf.20035

%Disclaimer:  These codes have only been tested for the conditions published
%in the manuscript. Numerical errors are likely outside of these bounds given
%the crude iteration schemes used.  Use at your own risk.

%Copyright (C) 2013 Michael Lamb <mpl@gps.caltech.edu>

% This program is free software: you can redistribute it and/or modify it 
% under the terms of the GNU General Public License as published by the 
% Free Software Foundation. You should have received a copy of the GNU 
% General Public License along with this program.  If not, see 
% http://www.gnu.org/licenses.

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%This makes the data for Fig 7 in Mackey and Lamb (2013)

%eroding boulder

tic



rad = 2000 %vector of initial boulder radius (mm) to work through



ttime = 40000

Er = 0.05

iterations = 200

sizes = length(rad);

q = 1;

for q = 1:sizes;

   rad(q);
    
        
radius = rad(q)
    
%runs multcirc500 from 0-10 rotations for a specified number of iterations.
%records statistics of boulder at end of each step.

%mcx is the output file for each MC run for a given number of iterations. 

load nuclide_sphere_Lal %xn1 yn1 zn1

rolls = 1; %start with 

for rolls = 1:15 %start loop iterating through increasing number of roll events. 
    %rolls '1' will map to mc1, an so on

    rolls
    
%metadata of each run    
mc.iterations = iterations; %number of iterations for each roll number - (monte carlo simulation)
mc.Er = Er; %specified erosion rate
mc.radius = radius; %specified initial radius
mc.concnd = []; %normalised concentration at end of each step (C* = meanconc*Er / Prod rate * efolding length)
mc.timend = []; %normalised time at end of each step (Time*Er/efolding length)

%matrices to collect info:
mc.varmean = []; %outer skin variance/mean
mc.mean = []; %mean skin conc
mc.var = []; %skin conc stdev

for h = 1:iterations, %start loop of iterations - monte carlo simulation 

[stats_all,stats]=  boulder_erode_lalMC(rad,rolls,Er,ttime); %calls program to run boulder modelling. output'stats' defined there

%populates mc with data from [stats] - adds column for each iteration
mc.varmean = [mc.varmean,stats_all(:,5)];
mc.mean = [mc.mean,stats_all(:,3)];
mc.var = [mc.var,stats_all(:,4)];
mc.concnd = [mc.concnd,stats_all(:,7)];
mc.timend = [mc.timend,stats_all(:,8)];  
h;




end

%calculates averages for all the MC runs
avgvarmean = mean(mc.varmean,2);
avgvar = mean(mc.var,2);
avgmean = mean(mc.mean,2);
stdev = std(mc.varmean,0,2);

%add stats to mc structure data files
mc.avgvarmean = avgvarmean;
mc.avgvar = avgvar;
mc.stdev = stdev;
mc.avgmean = avgmean;

%finally rename mc file 'mcx', where 'x' is the number of rolls
eval(['mc' num2str(rolls) '=mc'])

fprintf('mc batch complete')

end


xtime = linspace(500,40000,length(avgvar));

save_radius = ceil(radius)

filename = [ 'mcLal_eros_varrolls_n200_rad' num2str(save_radius) '.mat' ];
save(filename);


clear mc1 mc2 mc3 mc4 mc5 mc6 mc7 mc8 mc9 mc10 mc11 mc12 mc13 mc14 mc15  avgvarmeanF stdvarmeanF avgvar

end

toc