%This mfile was created in Matlab R2010b.  Results were published in the
%following paper (Mackey and Lamb, 2013).  Please cite the following paper should these codes be
%used for a publication.

%Mackey, B.H., and Lamb, M.P., 2013, 
%Deciphering boulder mobility and erosion from cosmogenic nuclide exposure dating: 
%Journal of Geophysical Research: Earth Surface,doi: 10.1002/jgrf.20035

%Disclaimer:  These codes have only been tested for the conditions published
%in the manuscript. Numerical errors are likely outside of these bounds given
%the crude iteration schemes used.  Use at your own risk.

%Copyright (C) 2013 Michael Lamb <mpl@gps.caltech.edu>

% This program is free software: you can redistribute it and/or modify it 
% under the terms of the GNU General Public License as published by the 
% Free Software Foundation. You should have received a copy of the GNU 
% General Public License along with this program.  If not, see 
% http://www.gnu.org/licenses.

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%plot boulder_erode_var_radius

%makes the big non-dimensional figure using data from the 0.05mm/yr erosion
%run. Er does not affect this plot as all non-dim

ab = load('var_boulder_diam_Er_005mm_yr_all1') %load data from previous file

%Do this to make it a structure array - easier to access with string text
%below

%empty matrices for pulled data to accumulate in
time_nd = [];
conc_nd = [];

rads = [500 1000 1500 2000 2500 3000 4000 5000 7500 10000 15000 25000 50000]; %radius of the eroded boulders (in mm)

cnt = [250 500 1000 2000 3000 5000]; %countours of radius to track 

p = 1; %loop of individual contour values

for p = 1:length(cnt)

q = 1 ;

for q = 1:length(rads) %loop of individual radius values

   
ac = ab.(['stats_all' num2str(rads(q))]); %pulls the relevant data from ab and names it ac

cnta = cnt(p);

x1 = find(ac(:,2)==cnta); %find the index of the value in the matrix

time_nd = [time_nd;ac(x1,8)]; %pull out the relavent non-dim values
conc_nd = [conc_nd;ac(x1,7)];

end

contplot = [time_nd,conc_nd]; %matrix of ND time and conc

time_nd = []; %clears matrix for next time
conc_nd = [];

cntx = cnt(p);

eval(['contplot' num2str(cntx) '=contplot']); %renames contplot with the relavant contour of radius

end


clear ab

load var_boulder_diam_Er_005mm_yr_all1 %load the raw data again not in the structure array
load flatsurf %the values for the case of a flat surface

figure


plflat = loglog(flatsurf.tstar,flatsurf.cstar, 'b-', 'linewidth', 2)
hold on

%plots all the non-dim evolution profiles for the varying radiuses

pl1 = plot(stats_all500(:,8),stats_all500(:,7),'k-')
pl2 = plot(stats_all1000(:,8),stats_all1000(:,7),'k-')
pl3 = plot(stats_all1500(:,8),stats_all1500(:,7),'k-')
pl4 = plot(stats_all2000(:,8),stats_all2000(:,7),'k-')
pl5 = plot(stats_all2500(:,8),stats_all2500(:,7),'k-')
pl6 = plot(stats_all3000(:,8),stats_all3000(:,7),'k-')
pl7 = plot(stats_all4000(:,8),stats_all4000(:,7),'k-')
pl8 = plot(stats_all5000(:,8),stats_all5000(:,7),'k-')
pl9 = plot(stats_all7500(:,8),stats_all7500(:,7),'k-')
pl10 = plot(stats_all10000(:,8),stats_all10000(:,7),'k-')
pl11 = plot(stats_all15000(:,8),stats_all15000(:,7),'k-')
pl12 = plot(stats_all25000(:,8),stats_all25000(:,7),'k-')
pl12a = plot(stats_all50000(:,8),stats_all50000(:,7),'k-')

%now plot the countours of non-dim radius
pl13 = plot(contplot250(:,1),contplot250(:,2), 'r-')
pl14 = plot(contplot500(:,1),contplot500(:,2), 'r-')
pl15 = plot(contplot1000(:,1),contplot1000(:,2), 'r-')
pl16 = plot(contplot2000(:,1),contplot2000(:,2), 'r-')
pl17 = plot(contplot3000(:,1),contplot3000(:,2), 'r-')
pl18 = plot(contplot5000(:,1),contplot5000(:,2), 'r-')

lg1 = legend([plflat pl1 pl12a pl13 pl18], 'flat surface', 'R* = 0.6', 'R* = 60', 'R* = 0.3', 'R* = 6')
set(lg1, 'location', 'NorthWest', 'fontsize', 8)

xlim([0.1 100])
ylim([0.1 1.1])

plot([3 3], [0.28 0.95])


xlabel('T* (non-dimensional time)')
ylabel('C* (non-dimensional nuclide concentration)')
